@@ -13,11 +13,9 @@
 #   under the License.
 
 import json
-import sys
 import tempfile
 
 import mock
-import six.moves.builtins as __builtin__
 
 from ironicclient.common.apiclient import exceptions
 from ironicclient.common import cliutils
@@ -48,11 +46,13 @@ class NodeShellTest(utils.BaseTestCase):
                'maintenance',
                'maintenance_reason',
                'name',
+               'network_interface',
                'power_state',
                'properties',
                'provision_state',
                'provision_updated_at',
                'reservation',
+               'resource_class',
                'target_power_state',
                'target_provision_state',
                'updated_at',
@@ -416,7 +416,7 @@ class NodeShellTest(utils.BaseTestCase):
         node_manager_mock.set_target_raid_config.assert_called_once_with(
             'node', expected_target_raid_config_string)
 
-    @mock.patch.object(n_shell, '_get_from_stdin', autospec=True)
+    @mock.patch.object(commonutils, 'get_from_stdin', autospec=True)
     def test_set_target_raid_config_stdin(self, stdin_read_mock):
         node_manager_mock = mock.MagicMock(spec=['set_target_raid_config'])
         client_mock = mock.MagicMock(spec=['node'], node=node_manager_mock)
@@ -432,7 +432,7 @@ class NodeShellTest(utils.BaseTestCase):
         client_mock.node.set_target_raid_config.assert_called_once_with(
             'node', expected_target_raid_config_string)
 
-    @mock.patch.object(n_shell, '_get_from_stdin', autospec=True)
+    @mock.patch.object(commonutils, 'get_from_stdin', autospec=True)
     def test_set_target_raid_config_stdin_exception(self, stdin_read_mock):
         client_mock = mock.MagicMock()
         stdin_read_mock.side_effect = exc.InvalidAttribute('bad')
@@ -486,10 +486,28 @@ class NodeShellTest(utils.BaseTestCase):
         args.provision_state = 'active'
         args.config_drive = 'foo'
         args.clean_steps = None
+        args.wait_timeout = None
 
         n_shell.do_node_set_provision_state(client_mock, args)
         client_mock.node.set_provision_state.assert_called_once_with(
             'node_uuid', 'active', configdrive='foo', cleansteps=None)
+        self.assertFalse(client_mock.node.wait_for_provision_state.called)
+
+    def test_do_node_set_provision_state_active_wait(self):
+        client_mock = mock.MagicMock()
+        args = mock.MagicMock()
+        args.node = 'node_uuid'
+        args.provision_state = 'active'
+        args.config_drive = 'foo'
+        args.clean_steps = None
+        args.wait_timeout = 0
+
+        n_shell.do_node_set_provision_state(client_mock, args)
+        client_mock.node.set_provision_state.assert_called_once_with(
+            'node_uuid', 'active', configdrive='foo', cleansteps=None)
+        client_mock.node.wait_for_provision_state.assert_called_once_with(
+            'node_uuid', expected_state='active', timeout=0,
+            poll_interval=n_shell._LONG_ACTION_POLL_INTERVAL)
 
     def test_do_node_set_provision_state_deleted(self):
         client_mock = mock.MagicMock()
@@ -498,6 +516,7 @@ class NodeShellTest(utils.BaseTestCase):
         args.provision_state = 'deleted'
         args.config_drive = None
         args.clean_steps = None
+        args.wait_timeout = None
 
         n_shell.do_node_set_provision_state(client_mock, args)
         client_mock.node.set_provision_state.assert_called_once_with(
@@ -510,6 +529,7 @@ class NodeShellTest(utils.BaseTestCase):
         args.provision_state = 'rebuild'
         args.config_drive = None
         args.clean_steps = None
+        args.wait_timeout = None
 
         n_shell.do_node_set_provision_state(client_mock, args)
         client_mock.node.set_provision_state.assert_called_once_with(
@@ -522,6 +542,7 @@ class NodeShellTest(utils.BaseTestCase):
         args.provision_state = 'deleted'
         args.config_drive = 'foo'
         args.clean_steps = None
+        args.wait_timeout = None
 
         self.assertRaises(exceptions.CommandError,
                           n_shell.do_node_set_provision_state,
@@ -535,6 +556,7 @@ class NodeShellTest(utils.BaseTestCase):
         args.provision_state = 'inspect'
         args.config_drive = None
         args.clean_steps = None
+        args.wait_timeout = None
 
         n_shell.do_node_set_provision_state(client_mock, args)
         client_mock.node.set_provision_state.assert_called_once_with(
@@ -547,6 +569,7 @@ class NodeShellTest(utils.BaseTestCase):
         args.provision_state = 'manage'
         args.config_drive = None
         args.clean_steps = None
+        args.wait_timeout = None
 
         n_shell.do_node_set_provision_state(client_mock, args)
         client_mock.node.set_provision_state.assert_called_once_with(
@@ -559,6 +582,7 @@ class NodeShellTest(utils.BaseTestCase):
         args.provision_state = 'provide'
         args.config_drive = None
         args.clean_steps = None
+        args.wait_timeout = None
 
         n_shell.do_node_set_provision_state(client_mock, args)
         client_mock.node.set_provision_state.assert_called_once_with(
@@ -572,13 +596,14 @@ class NodeShellTest(utils.BaseTestCase):
         args.config_drive = None
         clean_steps = '[{"step": "upgrade", "interface": "deploy"}]'
         args.clean_steps = clean_steps
+        args.wait_timeout = None
 
         n_shell.do_node_set_provision_state(client_mock, args)
         client_mock.node.set_provision_state.assert_called_once_with(
             'node_uuid', 'clean', configdrive=None,
             cleansteps=json.loads(clean_steps))
 
-    @mock.patch.object(n_shell, '_get_from_stdin', autospec=True)
+    @mock.patch.object(commonutils, 'get_from_stdin', autospec=True)
     def test_do_node_set_provision_state_clean_stdin(self, mock_stdin):
         clean_steps = '[{"step": "upgrade", "interface": "deploy"}]'
         mock_stdin.return_value = clean_steps
@@ -588,6 +613,7 @@ class NodeShellTest(utils.BaseTestCase):
         args.provision_state = 'clean'
         args.config_drive = None
         args.clean_steps = '-'
+        args.wait_timeout = None
 
         n_shell.do_node_set_provision_state(client_mock, args)
         mock_stdin.assert_called_once_with('clean steps')
@@ -595,7 +621,7 @@ class NodeShellTest(utils.BaseTestCase):
             'node_uuid', 'clean', configdrive=None,
             cleansteps=json.loads(clean_steps))
 
-    @mock.patch.object(n_shell, '_get_from_stdin', autospec=True)
+    @mock.patch.object(commonutils, 'get_from_stdin', autospec=True)
     def test_do_node_set_provision_state_clean_stdin_fails(self, mock_stdin):
         mock_stdin.side_effect = exc.InvalidAttribute('bad')
         client_mock = mock.MagicMock()
@@ -604,6 +630,7 @@ class NodeShellTest(utils.BaseTestCase):
         args.provision_state = 'clean'
         args.config_drive = None
         args.clean_steps = '-'
+        args.wait_timeout = None
 
         self.assertRaises(exc.InvalidAttribute,
                           n_shell.do_node_set_provision_state,
@@ -624,6 +651,7 @@ class NodeShellTest(utils.BaseTestCase):
             args.provision_state = 'clean'
             args.config_drive = None
             args.clean_steps = f.name
+            args.wait_timeout = None
 
             n_shell.do_node_set_provision_state(client_mock, args)
             client_mock.node.set_provision_state.assert_called_once_with(
@@ -637,6 +665,7 @@ class NodeShellTest(utils.BaseTestCase):
         args.provision_state = 'clean'
         args.config_drive = None
         args.clean_steps = None
+        args.wait_timeout = None
 
         # clean_steps isn't specified
         self.assertRaisesRegex(exceptions.CommandError,
@@ -653,6 +682,7 @@ class NodeShellTest(utils.BaseTestCase):
         args.config_drive = None
         clean_steps = '[{"step": "upgrade", "interface": "deploy"}]'
         args.clean_steps = clean_steps
+        args.wait_timeout = None
 
         # clean_steps specified but not cleaning
         self.assertRaisesRegex(exceptions.CommandError,
@@ -668,11 +698,41 @@ class NodeShellTest(utils.BaseTestCase):
         args.provision_state = 'abort'
         args.config_drive = None
         args.clean_steps = None
+        args.wait_timeout = None
 
         n_shell.do_node_set_provision_state(client_mock, args)
         client_mock.node.set_provision_state.assert_called_once_with(
             'node_uuid', 'abort', configdrive=None, cleansteps=None)
 
+    def test_do_node_set_provision_state_adopt(self):
+        client_mock = mock.MagicMock()
+        args = mock.MagicMock()
+        args.node = 'node_uuid'
+        args.provision_state = 'adopt'
+        args.config_drive = None
+        args.clean_steps = None
+        args.wait_timeout = 0
+
+        n_shell.do_node_set_provision_state(client_mock, args)
+        client_mock.node.set_provision_state.assert_called_once_with(
+            'node_uuid', 'adopt', cleansteps=None, configdrive=None)
+
+    def test_do_node_set_provision_state_abort_no_wait(self):
+        client_mock = mock.MagicMock()
+        args = mock.MagicMock()
+        args.node = 'node_uuid'
+        args.provision_state = 'abort'
+        args.config_drive = None
+        args.clean_steps = None
+        args.wait_timeout = 0
+
+        self.assertRaisesRegex(exceptions.CommandError,
+                               "not supported for provision state 'abort'",
+                               n_shell.do_node_set_provision_state,
+                               client_mock, args)
+        self.assertFalse(client_mock.node.set_provision_state.called)
+        self.assertFalse(client_mock.node.wait_for_provision_state.called)
+
     def test_do_node_set_console_mode(self):
         client_mock = mock.MagicMock()
         args = mock.MagicMock()
@@ -738,7 +798,7 @@ class NodeShellTest(utils.BaseTestCase):
                               maintenance=None, marker=None, limit=None,
                               sort_dir=None, sort_key=None, detail=False,
                               fields=None, provision_state=None, driver=None,
-                              json=False):
+                              json=False, resource_class=None):
         args = mock.MagicMock()
         args.node = node
         args.associated = associated
@@ -752,6 +812,7 @@ class NodeShellTest(utils.BaseTestCase):
         args.fields = fields
         args.driver = driver
         args.json = json
+        args.resource_class = resource_class
 
         return args
 
@@ -807,6 +868,24 @@ class NodeShellTest(utils.BaseTestCase):
         client_mock.node.list.assert_called_once_with(driver='fake',
                                                       detail=True)
 
+    def test_do_node_list_resource_class(self):
+        client_mock = mock.MagicMock()
+        args = self._get_client_mock_args(resource_class='foo',
+                                          detail=False)
+
+        n_shell.do_node_list(client_mock, args)
+        client_mock.node.list.assert_called_once_with(resource_class='foo',
+                                                      detail=False)
+
+    def test_do_node_list_detail_resource_class(self):
+        client_mock = mock.MagicMock()
+        args = self._get_client_mock_args(resource_class='foo',
+                                          detail=True)
+
+        n_shell.do_node_list(client_mock, args)
+        client_mock.node.list.assert_called_once_with(resource_class='foo',
+                                                      detail=True)
+
     def test_do_node_list_sort_key(self):
         client_mock = mock.MagicMock()
         args = self._get_client_mock_args(sort_key='created_at',
@@ -1037,60 +1116,3 @@ class NodeShellTest(utils.BaseTestCase):
         n_shell.do_node_get_vendor_passthru_methods(client_mock, args)
         client_mock.node.get_vendor_passthru_methods.assert_called_once_with(
             'node_uuid')
-
-
-class NodeShellLocalTest(utils.BaseTestCase):
-
-    @mock.patch.object(sys, 'stdin', autospec=True)
-    def test__get_from_stdin(self, mock_stdin):
-        contents = '[{"step": "upgrade", "interface": "deploy"}]'
-        mock_stdin.read.return_value = contents
-        desc = 'something'
-
-        info = n_shell._get_from_stdin(desc)
-        self.assertEqual(info, contents)
-        mock_stdin.read.assert_called_once_with()
-
-    @mock.patch.object(sys, 'stdin', autospec=True)
-    def test__get_from_stdin_fail(self, mock_stdin):
-        mock_stdin.read.side_effect = IOError
-        desc = 'something'
-
-        self.assertRaises(exc.InvalidAttribute, n_shell._get_from_stdin, desc)
-        mock_stdin.read.assert_called_once_with()
-
-    def test__handle_json_or_file_arg(self):
-        cleansteps = '[{"step": "upgrade", "interface": "deploy"}]'
-        steps = n_shell._handle_json_or_file_arg(cleansteps)
-        self.assertEqual(json.loads(cleansteps), steps)
-
-    def test__handle_json_or_file_arg_bad_json(self):
-        cleansteps = 'foo'
-        self.assertRaisesRegex(exc.InvalidAttribute,
-                               'For JSON',
-                               n_shell._handle_json_or_file_arg, cleansteps)
-
-    def test__handle_json_or_file_arg_file(self):
-        contents = '[{"step": "upgrade", "interface": "deploy"}]'
-
-        with tempfile.NamedTemporaryFile(mode='w') as f:
-            f.write(contents)
-            f.flush()
-            steps = n_shell._handle_json_or_file_arg(f.name)
-
-        self.assertEqual(json.loads(contents), steps)
-
-    @mock.patch.object(__builtin__, 'open', autospec=True)
-    def test__handle_json_or_file_arg_file_fail(self, mock_open):
-        mock_file_object = mock.MagicMock()
-        mock_file_handle = mock.MagicMock()
-        mock_file_handle.__enter__.return_value = mock_file_object
-        mock_open.return_value = mock_file_handle
-        mock_file_object.read.side_effect = IOError
-
-        with tempfile.NamedTemporaryFile(mode='w') as f:
-            self.assertRaisesRegex(exc.InvalidAttribute,
-                                   "from file",
-                                   n_shell._handle_json_or_file_arg, f.name)
-            mock_open.assert_called_once_with(f.name, 'r')
-            mock_file_object.read.assert_called_once_with()
