@@ -32,7 +32,7 @@ class PortShellTest(utils.BaseTestCase):
             port = object()
             p_shell._print_port_show(port)
         exp = ['address', 'created_at', 'extra', 'node_uuid', 'updated_at',
-               'uuid']
+               'uuid', 'pxe_enabled', 'local_link_connection', 'internal_info']
         act = actual.keys()
         self.assertEqual(sorted(exp), sorted(act))
 
