@@ -27,12 +27,13 @@ class Port(base.Resource):
 
 class PortManager(base.CreateManager):
     resource_class = Port
-    _creation_attributes = ['address', 'extra', 'node_uuid', 'uuid']
+    _creation_attributes = ['address', 'extra', 'local_link_connection',
+                            'node_uuid', 'pxe_enabled', 'uuid']
     _resource_name = 'ports'
 
     def list(self, address=None, limit=None, marker=None, sort_key=None,
-             sort_dir=None, detail=False, fields=None):
-        """Retrieve a list of port.
+             sort_dir=None, detail=False, fields=None, node=None):
+        """Retrieve a list of ports.
 
         :param address: Optional, MAC address of a port, to get
                        the port which has this MAC address
@@ -60,6 +61,9 @@ class PortManager(base.CreateManager):
                        of the resource to be returned. Can not be used
                        when 'detail' is set.
 
+        :param node: Optional, name or UUID of a node. Used to get
+                     ports of this node.
+
         :returns: A list of ports.
 
         """
@@ -74,6 +78,8 @@ class PortManager(base.CreateManager):
                                        fields)
         if address is not None:
             filters.append('address=%s' % address)
+        if node is not None:
+            filters.append('node=%s' % node)
 
         path = ''
         if detail:
